package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.BdForm;
import com.ruoyi.system.service.IBdFormService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 单Controller
 * 
 * @author ruoyi
 * @date 2022-11-27
 */
@RestController
@RequestMapping("/system/form")
public class BdFormController extends BaseController
{
    @Autowired
    private IBdFormService bdFormService;

    /**
     * 查询单列表
     */
    @PreAuthorize("@ss.hasPermi('system:form:list')")
    @GetMapping("/list")
    public TableDataInfo list(BdForm bdForm)
    {
        startPage();
        List<BdForm> list = bdFormService.selectBdFormList(bdForm);
        return getDataTable(list);
    }

    /**
     * 导出单列表
     */
    @PreAuthorize("@ss.hasPermi('system:form:export')")
    @Log(title = "单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BdForm bdForm)
    {
        List<BdForm> list = bdFormService.selectBdFormList(bdForm);
        ExcelUtil<BdForm> util = new ExcelUtil<BdForm>(BdForm.class);
        util.exportExcel(response, list, "单数据");
    }

    /**
     * 获取单详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:form:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bdFormService.selectBdFormById(id));
    }

    /**
     * 新增单
     */
    @PreAuthorize("@ss.hasPermi('system:form:add')")
    @Log(title = "单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BdForm bdForm)
    {
        return toAjax(bdFormService.insertBdForm(bdForm));
    }

    /**
     * 修改单
     */
    @PreAuthorize("@ss.hasPermi('system:form:edit')")
    @Log(title = "单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BdForm bdForm)
    {
        return toAjax(bdFormService.updateBdForm(bdForm));
    }

    /**
     * 删除单
     */
    @PreAuthorize("@ss.hasPermi('system:form:remove')")
    @Log(title = "单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bdFormService.deleteBdFormByIds(ids));
    }
}
