package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Fcry;
import com.ruoyi.system.service.IFcryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 方舱人员Controller
 * 
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/fcry")
public class FcryController extends BaseController
{
    @Autowired
    private IFcryService fcryService;

    /**
     * 查询方舱人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:list')")
    @GetMapping("/list")
    public TableDataInfo list(Fcry fcry)
    {
        startPage();
        List<Fcry> list = fcryService.selectFcryList(fcry);
        return getDataTable(list);
    }

    /**
     * 导出方舱人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:export')")
    @Log(title = "方舱人员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Fcry fcry)
    {
        List<Fcry> list = fcryService.selectFcryList(fcry);
        ExcelUtil<Fcry> util = new ExcelUtil<Fcry>(Fcry.class);
        util.exportExcel(response, list, "方舱人员数据");
    }

    /**
     * 获取方舱人员详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fcryService.selectFcryById(id));
    }

    /**
     * 新增方舱人员
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:add')")
    @Log(title = "方舱人员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Fcry fcry)
    {
        return toAjax(fcryService.insertFcry(fcry));
    }

    /**
     * 修改方舱人员
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:edit')")
    @Log(title = "方舱人员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Fcry fcry)
    {
        return toAjax(fcryService.updateFcry(fcry));
    }

    /**
     * 删除方舱人员
     */
    @PreAuthorize("@ss.hasPermi('system:fcry:remove')")
    @Log(title = "方舱人员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fcryService.deleteFcryByIds(ids));
    }
}
