package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Fkqk;
import com.ruoyi.system.service.IFkqkService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 小区封控情况Controller
 * 
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/fkqk")
public class FkqkController extends BaseController
{
    @Autowired
    private IFkqkService fkqkService;

    /**
     * 查询小区封控情况列表
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:list')")
    @GetMapping("/list")
    public TableDataInfo list(Fkqk fkqk)
    {
        startPage();
        List<Fkqk> list = fkqkService.selectFkqkList(fkqk);
        return getDataTable(list);
    }

    /**
     * 导出小区封控情况列表
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:export')")
    @Log(title = "小区封控情况", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Fkqk fkqk)
    {
        List<Fkqk> list = fkqkService.selectFkqkList(fkqk);
        ExcelUtil<Fkqk> util = new ExcelUtil<Fkqk>(Fkqk.class);
        util.exportExcel(response, list, "小区封控情况数据");
    }

    /**
     * 获取小区封控情况详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fkqkService.selectFkqkById(id));
    }

    /**
     * 新增小区封控情况
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:add')")
    @Log(title = "小区封控情况", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Fkqk fkqk)
    {
        return toAjax(fkqkService.insertFkqk(fkqk));
    }

    /**
     * 修改小区封控情况
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:edit')")
    @Log(title = "小区封控情况", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Fkqk fkqk)
    {
        return toAjax(fkqkService.updateFkqk(fkqk));
    }

    /**
     * 删除小区封控情况
     */
    @PreAuthorize("@ss.hasPermi('system:fkqk:remove')")
    @Log(title = "小区封控情况", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fkqkService.deleteFkqkByIds(ids));
    }
}
