package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Gldry;
import com.ruoyi.system.service.IGldryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 隔离点人员Controller
 * 
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/gldry")
public class GldryController extends BaseController
{
    @Autowired
    private IGldryService gldryService;

    /**
     * 查询隔离点人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:list')")
    @GetMapping("/list")
    public TableDataInfo list(Gldry gldry)
    {
        startPage();
        List<Gldry> list = gldryService.selectGldryList(gldry);
        return getDataTable(list);
    }

    /**
     * 导出隔离点人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:export')")
    @Log(title = "隔离点人员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Gldry gldry)
    {
        List<Gldry> list = gldryService.selectGldryList(gldry);
        ExcelUtil<Gldry> util = new ExcelUtil<Gldry>(Gldry.class);
        util.exportExcel(response, list, "隔离点人员数据");
    }

    /**
     * 获取隔离点人员详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gldryService.selectGldryById(id));
    }

    /**
     * 新增隔离点人员
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:add')")
    @Log(title = "隔离点人员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Gldry gldry)
    {
        return toAjax(gldryService.insertGldry(gldry));
    }

    /**
     * 修改隔离点人员
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:edit')")
    @Log(title = "隔离点人员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Gldry gldry)
    {
        return toAjax(gldryService.updateGldry(gldry));
    }

    /**
     * 删除隔离点人员
     */
    @PreAuthorize("@ss.hasPermi('system:gldry:remove')")
    @Log(title = "隔离点人员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gldryService.deleteGldryByIds(ids));
    }
}
