package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Hscj;
import com.ruoyi.system.service.IHscjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 核酸采集Controller
 * 
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/hscj")
public class HscjController extends BaseController
{
    @Autowired
    private IHscjService hscjService;

    /**
     * 查询核酸采集列表
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:list')")
    @GetMapping("/list")
    public TableDataInfo list(Hscj hscj)
    {
        startPage();
        List<Hscj> list = hscjService.selectHscjList(hscj);
        return getDataTable(list);
    }

    /**
     * 导出核酸采集列表
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:export')")
    @Log(title = "核酸采集", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Hscj hscj)
    {
        List<Hscj> list = hscjService.selectHscjList(hscj);
        ExcelUtil<Hscj> util = new ExcelUtil<Hscj>(Hscj.class);
        util.exportExcel(response, list, "核酸采集数据");
    }

    /**
     * 获取核酸采集详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(hscjService.selectHscjById(id));
    }

    /**
     * 新增核酸采集
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:add')")
    @Log(title = "核酸采集", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Hscj hscj)
    {
        return toAjax(hscjService.insertHscj(hscj));
    }

    /**
     * 修改核酸采集
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:edit')")
    @Log(title = "核酸采集", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Hscj hscj)
    {
        return toAjax(hscjService.updateHscj(hscj));
    }

    /**
     * 删除核酸采集
     */
    @PreAuthorize("@ss.hasPermi('system:hscj:remove')")
    @Log(title = "核酸采集", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(hscjService.deleteHscjByIds(ids));
    }
}
