package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Ycsb;
import com.ruoyi.system.service.IYcsbService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 抗原异常上报Controller
 * 
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/ycsb")
public class YcsbController extends BaseController
{
    @Autowired
    private IYcsbService ycsbService;

    /**
     * 查询抗原异常上报列表
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:list')")
    @GetMapping("/list")
    public TableDataInfo list(Ycsb ycsb)
    {
        startPage();
        List<Ycsb> list = ycsbService.selectYcsbList(ycsb);
        return getDataTable(list);
    }

    /**
     * 导出抗原异常上报列表
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:export')")
    @Log(title = "抗原异常上报", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Ycsb ycsb)
    {
        List<Ycsb> list = ycsbService.selectYcsbList(ycsb);
        ExcelUtil<Ycsb> util = new ExcelUtil<Ycsb>(Ycsb.class);
        util.exportExcel(response, list, "抗原异常上报数据");
    }

    /**
     * 获取抗原异常上报详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(ycsbService.selectYcsbById(id));
    }

    /**
     * 新增抗原异常上报
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:add')")
    @Log(title = "抗原异常上报", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Ycsb ycsb)
    {
        return toAjax(ycsbService.insertYcsb(ycsb));
    }

    /**
     * 修改抗原异常上报
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:edit')")
    @Log(title = "抗原异常上报", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Ycsb ycsb)
    {
        return toAjax(ycsbService.updateYcsb(ycsb));
    }

    /**
     * 删除抗原异常上报
     */
    @PreAuthorize("@ss.hasPermi('system:ycsb:remove')")
    @Log(title = "抗原异常上报", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(ycsbService.deleteYcsbByIds(ids));
    }
}
