package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Yxry;
import com.ruoyi.system.service.IYxryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 阳性人员Controller
 * 
 * @author ruoyi
 * @date 2022-11-28
 */
@RestController
@RequestMapping("/system/yxry")
public class YxryController extends BaseController
{
    @Autowired
    private IYxryService yxryService;

    /**
     * 查询阳性人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:list')")
    @GetMapping("/list")
    public TableDataInfo list(Yxry yxry)
    {
        startPage();
        List<Yxry> list = yxryService.selectYxryList(yxry);
        return getDataTable(list);
    }

    /**
     * 导出阳性人员列表
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:export')")
    @Log(title = "阳性人员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Yxry yxry)
    {
        List<Yxry> list = yxryService.selectYxryList(yxry);
        ExcelUtil<Yxry> util = new ExcelUtil<Yxry>(Yxry.class);
        util.exportExcel(response, list, "阳性人员数据");
    }

    /**
     * 获取阳性人员详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(yxryService.selectYxryById(id));
    }

    /**
     * 新增阳性人员
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:add')")
    @Log(title = "阳性人员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Yxry yxry)
    {
        return toAjax(yxryService.insertYxry(yxry));
    }

    /**
     * 修改阳性人员
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:edit')")
    @Log(title = "阳性人员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Yxry yxry)
    {
        return toAjax(yxryService.updateYxry(yxry));
    }

    /**
     * 删除阳性人员
     */
    @PreAuthorize("@ss.hasPermi('system:yxry:remove')")
    @Log(title = "阳性人员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(yxryService.deleteYxryByIds(ids));
    }
}
