package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysUser;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Zlqk;
import com.ruoyi.system.service.IZlqkService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 治疗情况Controller
 * 
 * @author ruoyi
 * @date 2022-11-27
 */
@RestController
@RequestMapping("/system/zlqk")
public class ZlqkController extends BaseController
{
    @Autowired
    private IZlqkService zlqkService;

    /**
     * 查询治疗情况列表
     */
    @PreAuthorize("@ss.hasPermi('system:zlqk:list')")
    @GetMapping("/list")
    public TableDataInfo list(Zlqk zlqk)
    {
        startPage();
        List<Zlqk> list = zlqkService.selectZlqkList(zlqk);
        return getDataTable(list);
    }

    /**
     * 导出治疗情况列表
     */
    @PreAuthorize("@ss.hasPermi('system:zlqk:export')")
    @Log(title = "治疗情况", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Zlqk zlqk)
    {
        List<Zlqk> list = zlqkService.selectZlqkList(zlqk);
        ExcelUtil<Zlqk> util = new ExcelUtil<Zlqk>(Zlqk.class);
        util.exportExcel(response, list, "治疗情况数据");
    }

    /**
     * 获取治疗情况详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:zlqk:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zlqkService.selectZlqkById(id));
    }

    /**
     * 新增治疗情况
     */
    @PreAuthorize("@ss.hasPermi('system:zlqk:add')")
    @Log(title = "治疗情况", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Zlqk zlqk)
    {
        return toAjax(zlqkService.insertZlqk(zlqk));
    }

    /**
     * 修改治疗情况
     */
    @PreAuthorize("@ss.hasPermi('system:zlqk:edit')")
    @Log(title = "治疗情况", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Zlqk zlqk)
    {
        return toAjax(zlqkService.updateZlqk(zlqk));
    }

    /**
     * 删除治疗情况
     */
    @PreAuthorize("@ss.hasPermi('system:zlqk:remove')")
    @Log(title = "治疗情况", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zlqkService.deleteZlqkByIds(ids));
    }


    @PostMapping("/importTemplate")
    @PreAuthorize("@ss.hasPermi('system:zlqk:add')")
    @Log(title = "下载治疗情况模板", businessType = BusinessType.IMPORT)
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<Zlqk> util = new ExcelUtil<Zlqk>(Zlqk.class);
        util.importTemplateExcel(response, "治疗情况");
    }

    @Log(title = "导入治疗情况", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('system:zlqk:add')")
    @PostMapping("/importData")
    public void importData(MultipartFile file,HttpServletResponse response) throws Exception
    {
        ExcelUtil<Zlqk> util = new ExcelUtil<Zlqk>(Zlqk.class);
        List<Zlqk> list = util.importExcel(file.getInputStream());
        zlqkService.importList(list, response);
    }
}
